@@ -5,7 +5,7 @@ use warnings;
 package Dist::Zilla::Plugin::BumpVersionAfterRelease;
 # ABSTRACT: Bump module versions after distribution release
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 use Moose;
 with(
@@ -155,7 +155,7 @@ Dist::Zilla::Plugin::BumpVersionAfterRelease - Bump module versions after distri
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -316,6 +316,12 @@ L<https://github.com/dagolden/Dist-Zilla-Plugin-BumpVersionAfterRelease>
 
 David Golden <dagolden@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Kent Fredric
+
+Kent Fredric <kentfredric@gmail.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2014 by David Golden.
